@@ -36,11 +36,17 @@
 ExportManager::ExportManager(QObject *parent)
     : QObject(parent)
     , m_imageSavedNotInTemp(false)
-    , m_savePixmap(QPixmap())
+    , m_saveImage(QImage())
     , m_tempFile(QUrl())
 {
-    connect(this, &ExportManager::imageSaved, &Settings::setLastSaveLocation);
-    connect(this, &ExportManager::imageSavedAndCopied, &Settings::setLastSaveLocation);
+    connect(this, &ExportManager::imageExported, [](Actions actions, const QUrl &url) {
+        if (actions & AnySave) {
+            Settings::setLastSaveLocation(url);
+            if (actions & SaveAs) {
+                Settings::setLastSaveAsLocation(url);
+            }
+        }
+    });
 }
 
 ExportManager::~ExportManager()
@@ -56,11 +62,11 @@ ExportManager *ExportManager::instance()
     return &instance;
 }
 
-// screenshot pixmap setter and getter
+// screenshot image setter and getter
 
-QPixmap ExportManager::pixmap() const
+QImage ExportManager::image() const
 {
-    return m_savePixmap;
+    return m_saveImage;
 }
 
 void ExportManager::setWindowTitle(const QString &windowTitle)
@@ -73,9 +79,9 @@ QString ExportManager::windowTitle() const
     return m_windowTitle;
 }
 
-void ExportManager::setPixmap(const QPixmap &pixmap)
+void ExportManager::setImage(const QImage &image)
 {
-    m_savePixmap = pixmap;
+    m_saveImage = image;
 
     // reset our saved tempfile
     if (m_tempFile.isValid()) {
@@ -85,20 +91,20 @@ void ExportManager::setPixmap(const QPixmap &pixmap)
         m_tempFile = QUrl();
     }
 
-    // since the pixmap was modified, we now consider the image unsaved
+    // since the image was modified, we now consider the image unsaved
     m_imageSavedNotInTemp = false;
 
-    Q_EMIT pixmapChanged();
+    Q_EMIT imageChanged();
 }
 
-void ExportManager::updatePixmapTimestamp()
+void ExportManager::updateTimestamp()
 {
-    m_pixmapTimestamp = QDateTime::currentDateTime();
+    m_timestamp = QDateTime::currentDateTime();
 }
 
 void ExportManager::setTimestamp(const QDateTime &timestamp)
 {
-    m_pixmapTimestamp = timestamp;
+    m_timestamp = timestamp;
 }
 
 // native file save helpers
@@ -169,7 +175,7 @@ QString ExportManager::truncatedFilename(QString const &filename) const
 
 QString ExportManager::formattedFilename(const QString &nameTemplate) const
 {
-    const QDateTime timestamp = m_pixmapTimestamp;
+    const QDateTime timestamp = m_timestamp;
     QString baseName = nameTemplate;
     QString baseDir = defaultSaveLocation();
     QString title = m_windowTitle;
@@ -321,7 +327,7 @@ bool ExportManager::writeImage(QIODevice *device, const QByteArray &suffix)
         return false;
     }
 
-    return imageWriter.write(m_savePixmap.toImage());
+    return imageWriter.write(m_saveImage);
 }
 
 bool ExportManager::localSave(const QUrl &url, const QString &suffix)
@@ -453,6 +459,7 @@ bool ExportManager::isFileExists(const QUrl &url) const
     if (!(url.isValid())) {
         return false;
     }
+    // Using StatJob instead of QFileInfo::exists() is necessary for checking non-local URLs.
     KIO::StatJob *existsJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails, KIO::HideProgressInfo);
 
     existsJob->exec();
@@ -470,117 +477,96 @@ bool ExportManager::isTempFileAlreadyUsed(const QUrl &url) const
     return m_usedTempFileNames.contains(url);
 }
 
-// save slots
-
-void ExportManager::doSave(const QUrl &url, bool notify)
+void ExportManager::exportImage(ExportManager::Actions actions, QUrl url)
 {
-    if (m_savePixmap.isNull()) {
+    if (m_saveImage.isNull() && actions & (Save | SaveAs | CopyImage)) {
         Q_EMIT errorMessage(i18n("Cannot save an empty screenshot image."));
         return;
     }
 
-    QUrl savePath = url.isValid() ? url : getAutosaveFilename();
-    if (save(savePath)) {
-        QDir dir(savePath.path());
-        dir.cdUp();
+    bool success = false;
+    if (actions & SaveAs) {
+        QStringList supportedFilters;
 
-        Q_EMIT imageSaved(savePath);
-        if (notify) {
-            Q_EMIT forceNotify(savePath);
+        // construct the supported mimetype list
+        const auto mimeTypes = QImageWriter::supportedMimeTypes();
+        supportedFilters.reserve(mimeTypes.count());
+        for (const auto &mimeType : mimeTypes) {
+            supportedFilters.append(QString::fromUtf8(mimeType).trimmed());
+        }
+
+        // construct the file name
+        const QString filenameExtension = Settings::self()->defaultSaveImageFormat().toLower();
+        const QString mimetype = QMimeDatabase().mimeTypeForFile(QStringLiteral("~/fakefile.") + filenameExtension, QMimeDatabase::MatchExtension).name();
+        QFileDialog dialog;
+        dialog.setAcceptMode(QFileDialog::AcceptSave);
+        dialog.setFileMode(QFileDialog::AnyFile);
+        QUrl dirUrl = url.adjusted(QUrl::RemoveFilename);
+        if (!dirUrl.isValid()) {
+            dirUrl = Settings::self()->lastSaveAsLocation().adjusted(QUrl::RemoveFilename);
+        }
+        dialog.setDirectoryUrl(dirUrl);
+        dialog.selectFile(formattedFilename() + QStringLiteral(".") + filenameExtension);
+        dialog.setDefaultSuffix(QStringLiteral(".") + filenameExtension);
+        dialog.setMimeTypeFilters(supportedFilters);
+        dialog.selectMimeTypeFilter(mimetype);
+
+        // launch the dialog
+        const bool accepted = dialog.exec() == QDialog::Accepted;
+        if (accepted && !dialog.selectedUrls().isEmpty()) {
+            url = dialog.selectedUrls().constFirst();
+        }
+        actions.setFlag(SaveAs, accepted && url.isValid());
+    }
+
+    bool saved = actions & AnySave;
+    if (saved) {
+        if (!url.isValid()) {
+            url = getAutosaveFilename();
+        }
+        saved = success = save(url);
+        if (!success) {
+            actions.setFlag(Save, false);
+            actions.setFlag(SaveAs, false);
         }
     }
-}
 
-bool ExportManager::doSaveAs(bool notify)
-{
-    QStringList supportedFilters;
-
-    // construct the supported mimetype list
-    const auto mimeTypes = QImageWriter::supportedMimeTypes();
-    supportedFilters.reserve(mimeTypes.count());
-    for (const auto &mimeType : mimeTypes) {
-        supportedFilters.append(QString::fromUtf8(mimeType).trimmed());
+    if (actions & CopyImage) {
+        auto data = new QMimeData();
+        data->setImageData(m_saveImage);
+        // "x-kde-force-image-copy" is handled by Klipper.
+        // It ensures that the image is copied to Klipper even with the
+        // "Non-text selection: Never save in history" setting selected in Klipper.
+        data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
+        KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
+        success = true;
     }
 
-    // construct the file name
-    const QString filenameExtension = Settings::self()->defaultSaveImageFormat().toLower();
-    const QString mimetype = QMimeDatabase().mimeTypeForFile(QStringLiteral("~/fakefile.") + filenameExtension, QMimeDatabase::MatchExtension).name();
-    QFileDialog dialog;
-    dialog.setAcceptMode(QFileDialog::AcceptSave);
-    dialog.setFileMode(QFileDialog::AnyFile);
-    dialog.setDirectoryUrl(Settings::self()->lastSaveAsLocation().adjusted(QUrl::RemoveFilename));
-    dialog.selectFile(formattedFilename() + QStringLiteral(".") + filenameExtension);
-    dialog.setDefaultSuffix(QStringLiteral(".") + filenameExtension);
-    dialog.setMimeTypeFilters(supportedFilters);
-    dialog.selectMimeTypeFilter(mimetype);
-
-    // launch the dialog
-    if (dialog.exec() == QFileDialog::Accepted) {
-        const QUrl saveUrl = dialog.selectedUrls().constFirst();
-        if (saveUrl.isValid()) {
-            if (save(saveUrl)) {
-                Q_EMIT imageSaved(saveUrl);
-                Settings::setLastSaveAsLocation(saveUrl);
-                if (notify) {
-                    Q_EMIT forceNotify(saveUrl);
-                }
-                return true;
+    if (actions & CopyPath
+        // This behavior has no relation to the setting in the config UI,
+        // but it was added to solve this feature request:
+        // https://bugs.kde.org/show_bug.cgi?id=357423
+        || (saved && Settings::clipboardGroup() == Settings::PostScreenshotCopyLocation)) {
+        if (!url.isValid()) {
+            if (m_imageSavedNotInTemp) {
+                // The image has been saved (manually or automatically),
+                // we need to choose that file path
+                url = Settings::self()->lastSaveLocation();
+            } else {
+                // use a temporary save path, and copy that to clipboard instead
+                url = ExportManager::instance()->tempSave();
             }
         }
-    }
-    return false;
-}
 
-void ExportManager::doSaveAndCopy(const QUrl &url)
-{
-    if (m_savePixmap.isNull()) {
-        Q_EMIT errorMessage(i18n("Cannot save an empty screenshot image."));
-        return;
+        // will be deleted for us by the platform's clipboard manager.
+        auto data = new QMimeData();
+        data->setText(url.toLocalFile());
+        KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
+        success = true;
     }
 
-    QUrl savePath = url.isValid() ? url : getAutosaveFilename();
-    if (save(savePath)) {
-        QDir dir(savePath.path());
-        dir.cdUp();
-
-        doCopyToClipboard(false);
-        Q_EMIT imageSavedAndCopied(savePath);
-    }
-}
-
-// misc helpers
-void ExportManager::doCopyToClipboard(bool notify)
-{
-    auto data = new QMimeData();
-    data->setImageData(m_savePixmap.toImage());
-    // "x-kde-force-image-copy" is handled by Klipper.
-    // It ensures that the image is copied to Klipper even with the
-    // "Non-text selection: Never save in history" setting selected in Klipper.
-    data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
-    KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
-    Q_EMIT imageCopied();
-    if (notify) {
-        Q_EMIT forceNotify(QUrl());
-    }
-}
-
-void ExportManager::doCopyLocationToClipboard(bool notify)
-{
-    QString localFile;
-    if (m_imageSavedNotInTemp) {
-        // The image has been saved (manually or automatically), we need to choose that file path
-        localFile = Settings::self()->lastSaveLocation().toLocalFile();
-    } else {
-        // use a temporary save path, and copy that to clipboard instead
-        localFile = ExportManager::instance()->tempSave().toLocalFile();
-    }
-
-    auto data = new QMimeData();
-    data->setText(localFile);
-    KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
-    Q_EMIT imageLocationCopied(QUrl::fromLocalFile(localFile));
-    if (notify) {
-        Q_EMIT forceNotify(QUrl::fromLocalFile(localFile));
+    if (success) {
+        Q_EMIT imageExported(actions, url);
     }
 }
 
@@ -596,11 +582,11 @@ void ExportManager::doPrint(QPrinter *printer)
     painter.setRenderHint(QPainter::LosslessImageRendering);
 
     QRect devRect(0, 0, printer->width(), printer->height());
-    QPixmap pixmap = m_savePixmap.scaled(devRect.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
-    QRect srcRect = pixmap.rect();
+    QImage image = m_saveImage.scaled(devRect.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    QRect srcRect = image.rect();
     srcRect.moveCenter(devRect.center());
 
-    painter.drawPixmap(srcRect.topLeft(), pixmap);
+    painter.drawImage(srcRect.topLeft(), image);
     painter.end();
 }
 
