@@ -11,7 +11,6 @@
 class QIODevice;
 #include <QMap>
 #include <QObject>
-#include <QPixmap>
 class QPrinter;
 #include <QUrl>
 
@@ -36,13 +35,24 @@ private:
     // now the usual stuff
 
 public:
+    enum Action {
+        NoActions = 0b0000,
+        Save      = 0b0001,
+        SaveAs    = 0b0010,
+        CopyImage = 0b0100,
+        CopyPath  = 0b1000,
+        AnySave   = Save | SaveAs,
+    };
+    Q_DECLARE_FLAGS(Actions, Action)
+    Q_FLAG(Action)
+
     QString defaultSaveLocation() const;
     QString defaultVideoSaveLocation() const;
     bool isFileExists(const QUrl &url) const;
     bool isImageSavedNotInTemp() const;
-    void setPixmap(const QPixmap &pixmap);
-    QPixmap pixmap() const;
-    void updatePixmapTimestamp();
+    void setImage(const QImage &image);
+    QImage image() const;
+    void updateTimestamp();
     void setTimestamp(const QDateTime &timestamp);
 
     /**
@@ -60,14 +70,10 @@ public:
     static const QMap<QString, KLocalizedString> filenamePlaceholders;
 
 Q_SIGNALS:
-    void pixmapChanged();
+    void imageChanged();
 
     void errorMessage(const QString &str);
-    void imageSaved(const QUrl &savedAt);
-    void imageCopied();
-    void imageLocationCopied(const QUrl &savedAt);
-    void imageSavedAndCopied(const QUrl &savedAt);
-    void forceNotify(const QUrl &savedAt);
+    void imageExported(const ExportManager::Actions &actions, const QUrl &url = {});
 
 public Q_SLOTS:
 
@@ -75,11 +81,7 @@ public Q_SLOTS:
     QUrl tempSave();
 
     void setWindowTitle(const QString &windowTitle);
-    void doSave(const QUrl &url = QUrl(), bool notify = false);
-    bool doSaveAs(bool notify = false);
-    void doSaveAndCopy(const QUrl &url = QUrl());
-    void doCopyToClipboard(bool notify = false);
-    void doCopyLocationToClipboard(bool notify = false);
+    void exportImage(ExportManager::Actions actions, QUrl url = {});
     void doPrint(QPrinter *printer);
 
 private:
@@ -94,10 +96,12 @@ private:
     bool isTempFileAlreadyUsed(const QUrl &url) const;
 
     bool m_imageSavedNotInTemp;
-    QPixmap m_savePixmap;
-    QDateTime m_pixmapTimestamp;
+    QImage m_saveImage;
+    QDateTime m_timestamp;
     QUrl m_tempFile;
     QTemporaryDir *m_tempDir = nullptr;
     QList<QUrl> m_usedTempFileNames;
     QString m_windowTitle;
 };
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(ExportManager::Actions)
