@@ -839,18 +839,8 @@ SelectedActionWrapper *AnnotationDocument::selectedActionWrapper() const
 
 void AnnotationDocument::clear()
 {
-    qDeleteAll(m_undoStack);
-    m_undoStack.clear();
-    m_undoStack.squeeze();
-    qDeleteAll(m_redoStack);
-    m_redoStack.clear();
-    m_redoStack.squeeze();
+    clearAnnotations();
     clearImages();
-    m_tool->resetType();
-    m_tool->resetNumber();
-    Q_EMIT undoStackDepthChanged();
-    Q_EMIT redoStackDepthChanged();
-    Q_EMIT repaintNeeded();
 }
 
 void AnnotationDocument::cropCanvas(const QRectF &cropRect)
@@ -880,8 +870,8 @@ void AnnotationDocument::cropCanvas(const QRectF &cropRect)
     }
     m_redoStack = filteredRedo;
 
-    for (auto &img : m_baseImages) {
-        img.pos -= (cropRect.topLeft());
+    for (auto &img : m_canvasImages) {
+        img.rect.setTopLeft(img.rect.topLeft() - cropRect.topLeft());
     }
 
     m_canvasSize = cropRect.size();
@@ -897,13 +887,13 @@ QSizeF AnnotationDocument::canvasSize() const
     return m_canvasSize;
 }
 
-void AnnotationDocument::addImage(const QImage &image, const QPointF &pos)
+void AnnotationDocument::addImage(const CanvasImage &canvasImage)
 {
-    m_baseImages << BaseImage({image, pos});
+    m_canvasImages << canvasImage;
 
     QRectF rect;
-    for (const auto &img : qAsConst(m_baseImages)) {
-        rect = rect.united(QRectF(img.pos, img.image.size() / img.image.devicePixelRatio()));
+    for (const auto &img : qAsConst(m_canvasImages)) {
+        rect = rect.united(img.rect);
     }
     m_canvasSize = rect.size();
 
@@ -911,24 +901,36 @@ void AnnotationDocument::addImage(const QImage &image, const QPointF &pos)
     Q_EMIT repaintNeeded();
 }
 
-QVector<QImage> AnnotationDocument::baseImages() const
+QVector<CanvasImage> AnnotationDocument::canvasImages() const
 {
-    QVector<QImage> imgs;
-    for (const auto &bi : qAsConst(m_baseImages)) {
-        imgs.append(bi.image);
-    }
-    return imgs;
+    return m_canvasImages;
 }
 
 void AnnotationDocument::clearImages()
 {
-    m_baseImages.clear();
-    m_baseImages.squeeze();
+    m_canvasImages.clear();
+    m_canvasImages.squeeze();
     m_canvasSize = QSizeF();
     Q_EMIT canvasSizeChanged();
     Q_EMIT repaintNeeded();
 }
 
+void AnnotationDocument::clearAnnotations()
+{
+    qDeleteAll(m_undoStack);
+    m_undoStack.clear();
+    m_undoStack.squeeze();
+    qDeleteAll(m_redoStack);
+    m_redoStack.clear();
+    m_redoStack.squeeze();
+    m_tool->resetType();
+    m_tool->resetNumber();
+    deselectAction();
+    Q_EMIT undoStackDepthChanged();
+    Q_EMIT redoStackDepthChanged();
+    Q_EMIT repaintNeeded();
+}
+
 inline QPointF zoomPoint(const QPointF &pos, qreal zoomFactor)
 {
     return QPointF(pos.x() * zoomFactor, pos.y() * zoomFactor);
@@ -949,12 +951,12 @@ void AnnotationDocument::paint(QPainter *painter, const QRectF &viewPort, qreal
     static QList<EditAction *> stopAtAction = QList<EditAction *>();
     const qreal scale = painter->transform().m11();
 
-    for (const auto &img : qAsConst(m_baseImages)) {
-        if (viewPort.intersects(QRectF(img.pos, img.image.size()))) {
+    for (const auto &img : qAsConst(m_canvasImages)) {
+        if (viewPort.intersects(img.rect)) {
             // More High quality scale down
             auto scaledImg = img.image.scaled(zoomSize(img.image.size(), zoomFactor).toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
             scaledImg.setDevicePixelRatio(img.image.devicePixelRatio());
-            painter->drawImage(zoomPoint(img.pos - viewPort.topLeft(), zoomFactor).toPoint(), scaledImg);
+            painter->drawImage(zoomPoint(img.rect.topLeft() - viewPort.topLeft() * img.image.devicePixelRatio(), zoomFactor).toPoint(), scaledImg);
         }
     }
 
