@@ -13,6 +13,8 @@
 #include "Gui/SelectionEditor.h"
 #include "spectacle_gui_debug.h"
 
+#include <QScreen>
+
 QVector<CaptureWindow *> CaptureWindow::s_captureWindowInstances = {};
 
 CaptureWindow::CaptureWindow(Mode mode, QScreen *screen, QQmlEngine *engine, QWindow *parent)
@@ -38,7 +40,6 @@ CaptureWindow::CaptureWindow(Mode mode, QScreen *screen, QQmlEngine *engine, QWi
     connect(selectionEditor, &SelectionEditor::screensRectChanged, this, [this]() {
         syncGeometryWithScreen();
     });
-    connect(selectionEditor, &SelectionEditor::screenImagesChanged, this, &CaptureWindow::screenCaptureUrlChanged);
     connect(this, &CaptureWindow::devicePixelRatioChanged,
             selectionEditor, &SelectionEditor::devicePixelRatioChanged);
 
@@ -57,7 +58,6 @@ CaptureWindow::CaptureWindow(Mode mode, QScreen *screen, QQmlEngine *engine, QWi
     syncGeometryWithScreen();
     Q_EMIT screenToFollowChanged();
     Q_EMIT devicePixelRatioChanged(m_screenToFollow->devicePixelRatio());
-    Q_EMIT screenCaptureUrlChanged();
 
     // sync visibility
     connect(this, &QWindow::visibilityChanged, this, [this](QWindow::Visibility visibility){
@@ -85,8 +85,10 @@ CaptureWindow::~CaptureWindow()
 
 CaptureWindow::UniquePointer CaptureWindow::makeUnique(Mode mode, QScreen *screen, QQmlEngine *engine, QWindow *parent)
 {
-    return UniquePointer(new CaptureWindow(mode, screen, engine, parent),
-                         &SpectacleWindow::deleter);
+    return UniquePointer(new CaptureWindow(mode, screen, engine, parent), [](CaptureWindow *window){
+        s_captureWindowInstances.removeOne(window);
+        deleter(window);
+    });
 }
 
 QVector<CaptureWindow *> CaptureWindow::instances()
@@ -99,15 +101,6 @@ QScreen *CaptureWindow::screenToFollow() const
     return m_screenToFollow;
 }
 
-QString CaptureWindow::screenCaptureUrl() const
-{
-    if (!m_screenToFollow) {
-        return QString();
-    }
-    return QStringLiteral("image://spectacle/screen/") + m_screenToFollow->name() + QLatin1Char('/')
-        + QString::number(SelectionEditor::instance()->imageForScreen(m_screenToFollow).cacheKey());
-}
-
 void CaptureWindow::setMode(CaptureWindow::Mode mode)
 {
     if (mode == Image) {
@@ -130,26 +123,22 @@ bool CaptureWindow::accept()
 
 void CaptureWindow::save()
 {
-    accept();
-    SpectacleWindow::save();
+    SelectionEditor::instance()->acceptSelection(ExportManager::Save);
 }
 
 void CaptureWindow::saveAs()
 {
-    accept();
-    SpectacleWindow::saveAs();
+    SelectionEditor::instance()->acceptSelection(ExportManager::SaveAs);
 }
 
 void CaptureWindow::copyImage()
 {
-    accept();
-    SpectacleWindow::copyImage();
+    SelectionEditor::instance()->acceptSelection(ExportManager::CopyImage);
 }
 
 void CaptureWindow::copyLocation()
 {
-    accept();
-    SpectacleWindow::copyLocation();
+    SelectionEditor::instance()->acceptSelection(ExportManager::Save | ExportManager::CopyPath);
 }
 
 void CaptureWindow::mousePressEvent(QMouseEvent *event)
