@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include "ScreenImage.h"
+#include "CanvasImage.h"
 
 #include <QFlags>
 #include <QObject>
@@ -49,8 +49,8 @@ public Q_SLOTS:
 Q_SIGNALS:
     void supportedGrabModesChanged();
 
-    void newScreenshotTaken(const QPixmap &thePixmap);
-    void newScreensScreenshotTaken(const QVector<ScreenImage> &screenImages);
+    void newScreenshotTaken(const QImage &image = {});
+    void newScreensScreenshotTaken(const QVector<CanvasImage> &screenImages);
 
     void newScreenshotFailed();
     void windowTitleChanged(const QString &theWindowTitle = {});
