@@ -39,13 +39,15 @@ public:
         Screen = 1,
     };
 
-    QString platformName() const override;
     GrabModes supportedGrabModes() const override;
     ShutterModes supportedShutterModes() const override;
 
 public Q_SLOTS:
     void doGrab(Platform::ShutterMode theShutterMode, Platform::GrabMode theGrabMode, bool theIncludePointer, bool theIncludeDecorations) override;
 
+private Q_SLOTS:
+    void updateSupportedGrabModes();
+
 private:
     explicit PlatformKWinWayland2(QObject *parent = nullptr);
 
@@ -59,6 +61,7 @@ private:
     void trackSource(ScreenShotSourceMeta2 *source);
 
     int m_apiVersion = 1;
+    GrabModes m_grabModes;
 };
 
 /**
